remove 'get' prefix in methods
diff --git a/openstack/storage/v1/objects/urls.go b/openstack/storage/v1/objects/urls.go
index 5a52aed..a377960 100644
--- a/openstack/storage/v1/objects/urls.go
+++ b/openstack/storage/v1/objects/urls.go
@@ -2,12 +2,12 @@
 
 import "github.com/rackspace/gophercloud"
 
-// getObjectURL returns the URI for making Object requests.
-func getObjectURL(c *gophercloud.ServiceClient, container, object string) string {
+// objectURL returns the URI for making Object requests.
+func objectURL(c *gophercloud.ServiceClient, container, object string) string {
 	return c.ServiceURL(container, object)
 }
 
-// getContainerURL returns the URI for making Container requests.
-func getContainerURL(c *gophercloud.ServiceClient, container string) string {
+// containerURL returns the URI for making Container requests.
+func containerURL(c *gophercloud.ServiceClient, container string) string {
 	return c.ServiceURL(container)
 }